@@ -1,11 +1,10 @@
 # mergeutil.py - help for merge processing in mercurial
 #
-# Copyright 2005-2007 Matt Mackall <mpm@selenic.com>
+# Copyright 2005-2007 Olivia Mackall <olivia@selenic.com>
 #
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
 
 from .i18n import _
 
@@ -13,7 +12,7 @@ from . import error
 
 
 def checkunresolved(ms):
-    if list(ms.unresolved()):
-        raise error.Abort(
+    if ms.unresolvedcount():
+        raise error.StateError(
             _(b"unresolved merge conflicts (see 'hg help resolve')")
         )
